@@ -10,6 +10,7 @@ def getOrElse(default, value):
         return default
 
 
+black = "black"
 blue = "blue"
 closed = "closed"
 create = "create"
@@ -20,6 +21,7 @@ green = "green"
 made = "made"
 new = "new"
 new_man = "new_man"
+orange = "orange"
 red = "red"
 restarted = "restarted"
 started = "started"
