@@ -84,6 +84,7 @@ def create_view(sql_str, params=[], view_name=None) -> None:
 def create_insert_update_delete_function_of_table(
         table_name,
         table_schema='public',
+        exclude_fields=[],
         func_params=[('id', 'bigint')],
         pk_names=['id']
 ):
@@ -102,6 +103,7 @@ def create_insert_update_delete_function_of_table(
             cursor.execute(columns_sql_str, [table_schema, f'{table_name}_view'])
             rows = cursor.fetchall()
 
+            pk_names.extend(exclude_fields)
             rows_without_pk_field = [row for row in rows if row[0] not in pk_names]
 
             def func_param_str(param_item):
@@ -203,9 +205,13 @@ def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, pa
         if not isinstance(primary_key, list):
             primary_key = [primary_key]
 
+        # pk_str = f'''ALTER TABLE {table_name}
+        #             ADD CONSTRAINT {table_name}_pk
+        #                 PRIMARY KEY ({','.join(primary_key)});'''
+
         pk_str = f'''ALTER TABLE {table_name}
-                    ADD CONSTRAINT {table_name}_pk
-                        PRIMARY KEY ({','.join(primary_key)});'''
+                            ADD CONSTRAINT {table_name}_pk
+                                UNIQUE ({','.join(primary_key)});'''
 
     indexes_str = ''
     if isinstance(indexes, list):
